'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const stylable_1 = require("stylable");
const provider_1 = require("./provider");
const htap_1 = require("htap");
var completion_types_1 = require("./completion-types");
exports.Completion = completion_types_1.Completion;
var completion_providers_1 = require("./completion-providers");
exports.ProviderRange = completion_providers_1.ProviderRange;
exports.ProviderPosition = completion_providers_1.ProviderPosition;
var diagnosis_1 = require("./diagnosis");
exports.createDiagnosis = diagnosis_1.createDiagnosis;
function createProvider(stylable, withFilePrefix = true) {
    // const styl = new Stylable('/', createFs(docs, fileSystem, withFilePrefix), () => ({ default: {} }))
    return new provider_1.default(stylable);
}
exports.createProvider = createProvider;
function createFs(fileSystem, withFilePrefix = true) {
    const getDocFormatPath = (path) => {
        if (process.platform === 'win32') {
            return withFilePrefix ? 'file:///' + htap_1.htap(path) : htap_1.htap(path);
        }
        else {
            return withFilePrefix ? 'file://' + path : path;
        }
    };
    return {
        readFileSync(path) {
            return fileSystem.loadTextFileSync(path).toString();
        },
        statSync(path) {
            return {
                mtime: new Date(Date.now())
            };
        }
    };
}
exports.createFs = createFs;
function createProcessor(fileSystem, withFilePrefix = true) {
    let proccesor = stylable_1.cachedProcessFile((fullpath, content) => {
        return stylable_1.process(stylable_1.safeParse(content, { from: fullpath }));
    }, createFs(fileSystem, withFilePrefix));
    return proccesor;
}
exports.createProcessor = createProcessor;
//# sourceMappingURL=provider-factory.js.map